// page初始化
function initPage() {
    printLog("initPage");
	initVars();
	initInnerBridge();
}

// 页面元素初始化
function initVars() {
	printLog("initVars");

	header = document.getElementsByTagName("header")[0];
	article = document.getElementsByTagName("article")[0];
	footer = document.getElementsByTagName("footer")[0];
}

// innerBridge初始化
function initInnerBridge() {
	printLog("initInnerBridge");

    innerBridgeElement=document.createElement("script");
    innerBridgeElement.setAttribute("type","text/javascript");
    innerBridgeElement.setAttribute("src","inner_bridge.js");
    document.body.appendChild(innerBridgeElement);
	connectInnerBridge(function(innerBridge) {
	    printLog("connectInnerBridge");
		
	    // 初始化，注册默认消息处理函数
		innerBridge.init(function(message, responseCallback) {
			printLog('defaultMessageHandler message:', message);
			if (responseCallback) {
			    responseCallback("defaultMessageHandler ret");
			}
		});
		
		initInnerImageManager();
	});
}

// innerImageManager初始化
function initInnerImageManager() {
	printLog("initInnerImageManager");
	
	innerImageManangerElement=document.createElement("script");
	innerImageManangerElement.setAttribute("type","text/javascript");
	innerImageManangerElement.setAttribute("src","inner_image_manager.js");
	document.body.appendChild(innerImageManangerElement);
	connectInnerImageManager(function(innerImageManager) {
		printLog("connectInnerImageManager");
		innerImageManager.init();

		initInnerNewsMananger();
	});
}

// innerNewsManager初始化
function initInnerNewsMananger() {
	printLog("initInnerNewsMananger");
	
    innerNewsManangerElement=document.createElement("script");
	innerNewsManangerElement.setAttribute("type","text/javascript");
	innerNewsManangerElement.setAttribute("src","inner_news_manager.js");
	document.body.appendChild(innerNewsManangerElement);
	connectInnerNewsManager(function(innerNewsManager) {
		printLog("connectInnerNewsManager");
		innerNewsManager.init();
		
		initInnerAdManager();
	});
}

// innerAdManager初始化
function initInnerAdManager() {
	printLog("initInnerAdManager");
	
	innerAdManangerElement=document.createElement("script");
	innerAdManangerElement.setAttribute("type","text/javascript");
	innerAdManangerElement.setAttribute("src","inner_ad_manager.js");
	document.body.appendChild(innerAdManangerElement);
	connectInnerAdManager(function(innerAdManager) {
		printLog("connectInnerAdManager");
		innerAdManager.init();
		
		printLog("======================================");
		registerFunctions();
	});
}

// 注册所有js端函数接口
function registerFunctions() {
    printLog("registerFunctions");
	
    // 注册渲染页面接口
	window.InnerBridge.registerHandler("jsFunctionRenderPage", jsFunctionRenderPage);
	
    // 注册用户点赞接口
	window.InnerBridge.registerHandler("jsFunctionUserLike", jsFunctionUserLike);
}

function start() {
    printLog("start begin");
	
    // 注册滚动事件监控
	document.addEventListener("scroll", pollLoop, false);

	// 加载默认图片
	setTimeout(function() {
		window.InnerImageManager.showImages();
	},
	300);

	// 延时加载网络图片
	setTimeout(function() {
		window.InnerImageManager.showImagesLazy();
	},
	400);
	
	// 请求相关新闻
	setTimeout(function() {
		window.InnerBridge.callHandler("funcRequestNews", "none", false);
	},
	100);
	
	// 请求相关广告
	setTimeout(function() {
		window.InnerBridge.callHandler("funcRequestAd", "none", false);
	},
	200);
		
	// 渲染页面
	setTimeout(function() {
		window.InnerBridge.callHandler("funcRenderPage", "none", false);
	},
	200);
	
	printLog("start end");
}

function connectInnerBridge(innerBridgeInitFunction) {
	if (window.InnerBridge) {
		innerBridgeInitFunction(InnerBridge)
	} else {
		document.addEventListener(
			'InnerBridgeReady'
			, function() {
				innerBridgeInitFunction(InnerBridge)
			},
			false
		);
	}
}

function connectInnerImageManager(innerImageManagerInitFunction) {
	if (window.InnerImageManager) {
		innerImageManagerInitFunction(InnerImageManager)
	} else {
		document.addEventListener(
			'InnerImageManagerReady'
			, function() {
				innerImageManagerInitFunction(InnerImageManager)
			},
			false
		);
	}
}

function connectInnerNewsManager(innerNewsManagerInitFunction) {
	if (window.InnerNewsManager) {
		innerNewsManagerInitFunction(InnerNewsManager)
	} else {
		document.addEventListener(
			'InnerNewsManagerReady'
			, function() {
				innerNewsManagerInitFunction(InnerNewsManager)
			},
			false
		);
	}
}

function connectInnerAdManager(innerAdManagerInitFunction) {
	if (window.InnerAdManager) {
		innerAdManagerInitFunction(InnerAdManager)
	} else {
		document.addEventListener(
			'InnerAdManagerReady'
			, function() {
				innerAdManagerInitFunction(InnerAdManager)
			},
			false
		);
	}
}

function pollLoop() {
    window.InnerImageManager.poolLoop();
	window.InnerAdManager.poolLoop();
	window.InnerNewsManager.poolLoop();
}

// 渲染页面
function jsFunctionRenderPage(data, responseCallback) {
	newsItem = JSON.parse(data);
	printLog("jsFunctionRenderPage");

	// 标题
	printLog("jsFunctionRenderPage title:" + newsItem.title);
	printLog("jsFunctionRenderPage publishTime:" + newsItem.publishTime);
	printLog("jsFunctionRenderPage source:" + newsItem.media.source);
	
	var headerElement = document.getElementsByTagName("header")[0];
	var htmlTemp = "<div id ='header_div'><div class='title'>"+ newsItem.title + "</div><div class='subtitle'>" + newsItem.publishTime + "　" + newsItem.media.source + "</div></div>";
	headerElement.innerHTML = htmlTemp;

	// 查看原文
	printLog("jsFunctionRenderPage srcUrl:" + newsItem.srcUrl);
	var footerElement = document.getElementsByTagName("footer")[0];
	htmlTemp = "<div id='footer_div'><div id='footer_original'><a id='footer_original_link' href='javascript:void(0)' originalurl='" + newsItem.srcUrl + "' onclick='startOriginalPage.call(this)'>查看原文</a></div>";

	// 收藏/点赞
	htmlTemp += "<div id='footer_like'><center><img id='footer_like_image' width='62' height='62' src='news_dislike.png' onclick='likeIt()'/></center><center><div id='footer_like_count' class='footer_like_count'>" + newsItem.userLikes + "</div></center><center><div class='footer_like_title'>喜欢请点赞，会推荐更多此类内容</div></center></div></div>";
	
	footerElement.innerHTML = htmlTemp;

	if (responseCallback) {
		responseCallback("jsFunctionRenderPage ret");
	}

	console.log("jsFunctionRenderPage OK1 " + headerElement.innerHTML);
	console.log("jsFunctionRenderPage OK2 " + footerElement.innerHTML);
	var like = '{"likeType":"unknown"}';
	window.InnerBridge.callHandler("funcUserLike", encodeURIComponent(like), false);
}

// 用户点赞 jsFunctionUserLike
function jsFunctionUserLike(data, responseCallback) {
	console.log("test setLikeStatus");
			
	var result = JSON.parse(data);
	var likeType = result.likeType;
	var likeImage = document.getElementById("footer_like_image");
	var count = parseInt(result.likeCount);
	var likeCount = document.getElementById("footer_like_count");
	if (likeType == "like") {
		likeImage.setAttribute("src", "news_like.png");
		likeCount.innerHTML = count + "";
	} else if (likeType == "dislike") {
		likeImage.setAttribute("src", "news_dislike.png");
		likeCount.innerHTML = count + "";
	} else {
		console.log("error:unknown type!");
	}
	
}

function startOriginalPage() {
	var originalurl = this.getAttribute("originalurl");
	if (originalurl) {
	    printLog("startOriginalPage originalurl:" + originalurl);
	    window.InnerBridge.callHandler("funcStartOriginalPage", encodeURIComponent(originalurl), false);
	}
}

function likeIt() {
    printLog("likeIt");
	
	var likeImage = document.getElementById("footer_like_image");
	var likeType = "unknown";
	var likeCount = document.getElementById("footer_like_count");
	var count = parseInt(likeCount.innerHTML);
	if (likeImage.getAttribute("src") == "news_like.png") {
		likeType = "dislike";
		likeImage.setAttribute("src", "news_dislike.png");
		count = count - 1;
		likeCount.innerHTML = count + "";
	} else if (likeImage.getAttribute("src") == "news_dislike.png") {
		likeType = "like";
		likeImage.setAttribute("src", "news_like.png");
		count = count + 1;
		likeCount.innerHTML = count + "";
	}
	
	var like = '{"likeType":"' + likeType + '"}';
	window.InnerBridge.callHandler("funcUserLike", encodeURIComponent(like), false);
}

// 根据屏幕尺寸跳转图片大小
function adjustOriginScale(width, height, screenWidth) {
	screenWidth -= 32;
	var realScreenWidth = 1.0 * screenWidth;
	if (width <= 0) {
		width = 200;
	}
	
	var adjustedWidth = width;
	var adjustedHeight = 0;
	
	if (adjustedWidth > realScreenWidth) {
		adjustedWidth = realScreenWidth;
	}

	adjustedHeight = parseInt(height * adjustedWidth / width);
	
	if (adjustedHeight <= 0) {
		adjustedHeight = 200;
	}
	
	var adjustedImage = {"w":adjustedWidth, "h":adjustedHeight};
	return adjustedImage;
}

// 查看图片是否在显示的屏幕内
function inView(image) {
	var rect = image.getBoundingClientRect();
	if (rect.top < 0) {
		return false;
	}
	
	if (rect.top >= 0 && rect.left >= 0) {
		if (window.innerHeight > 0) {
			if (rect.top <= (window.innerHeight + offset)) {
				return true;
			}
		}
		if (document.body.clientHeight > 0) {
			if (rect.top <= (document.body.clientHeight + offset)) {
				return true;
			}
		}
	}
	return false;
}

// 获取指定url的参数
function getURLParam(url, strParamName) {
	var strReturn = "";
	var strHref = url.toLowerCase();
	if (strHref.indexOf("?") > -1) {
		var strQueryString = strHref.substr(strHref.indexOf("?") + 1).toLowerCase();
		var aQueryString = strQueryString.split("&");
		for (var iParam = 0; iParam < aQueryString.length; iParam++) {
			if (aQueryString[iParam].indexOf(strParamName.toLowerCase() + "=") > -1) {
				var aParam = aQueryString[iParam].split("=");
				strReturn = aParam[1];
				break;
			}
		}
	}
	return strReturn;
}

function printLog(log) {
    console.log(log);
}

var header;
var article;
var footer;
var offset = 150;

document.addEventListener("DOMContentLoaded", initPage, false);
window.onload = function(){
	start();
};